package com.djhk.uav.uav.service;




import com.djhk.uav.uav.model.UavRealInfo;

import java.util.List;

/**
 * 靶机库反制设备对应机型实测数据  Service接口
 *
 * @author zhulongchuan
 * @date 2024-11-11
 */
public interface IUavRealInfoService
{

    /**
     * 查询靶机库反制设备对应机型实测数据
     *
     * @param uavId 靶机库反制设备对应机型实测数据主键
     * @return 靶机库反制设备对应机型实测数据
     */
    public UavRealInfo selectUavRealInfoByUavId(Long uavId);

    /**
     * 查询靶机库反制设备对应机型实测数据列表
     *
     * @param UavRealInfoVo 靶机库反制设备对应机型实测数据
     * @return 靶机库反制设备对应机型实测数据集合
     */
    public List<UavRealInfo> selectUavRealInfoList(UavRealInfo UavRealInfoVo);

    /**
     * 新增靶机库反制设备对应机型实测数据
     *
     * @param UavRealInfo 靶机库反制设备对应机型实测数据
     * @return 结果
     */
    public int insertUavRealInfo(UavRealInfo UavRealInfo);

    /**
     * 修改靶机库反制设备对应机型实测数据
     *
     * @param UavRealInfo 靶机库反制设备对应机型实测数据
     * @return 结果
     */
    public int updateUavRealInfo(UavRealInfo UavRealInfo);

    /**
     * 删除靶机库反制设备对应机型实测数据
     *
     * @param uavId 靶机库反制设备对应机型实测数据主键
     * @return 结果
     */
    public int deleteUavRealInfoByUavId(Long uavId);

    /**
     * 批量删除靶机库反制设备对应机型实测数据
     *
     * @param uavIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteUavRealInfoByUavIds(Long[] uavIds);
}
